Your message dated Tue, 24 Jul 2012 17:02:18 +0000
with message-id <[email protected]>
and subject line Bug#668888: fixed in urfkill 0.4.0-1
has caused the Debian Bug report #668888,
regarding urfkill: reads accelerometer device, causing lots of pointless wakeups
to be marked as done.
This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.
(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact [email protected]
immediately.)
--
668888: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=668888
Debian Bug Tracking System
Contact [email protected] with problems
--- Begin Message ---
Package: urfkill
Version: 0.3.0-1
Severity: normal
Tags: upstream patch
Dear Maintainer,
urfkill opens the accelerometer device on my laptop and waits for data
from it in an attempt to find any EV_KEY events which might be relevant.
The accelerometer generates continous data, so having the input device
open means that a kernel thread polls about 20 times / second and that
urfkilld wakes up with the same frequency (thanks powertop).
There is some code in src/urf-input.c which excludes e.g. PC speakers
from consideration, but the "blacklist" approach seems likely to fail in
the future if and when other platform devices are added.
I've attached a patch which checks if an input device has the EV_KEY
capabilities before using it (which excludes both the PC speaker and the
accelerometer).
Please consider applying (and upstreaming).
--
David Härdeman
--- a/src/urf-input.c
+++ b/src/urf-input.c
@@ -65,11 +65,14 @@
struct udev_device *platform_dev;
const char *platform_driver;
const char *dev_name;
+ const char *ev_caps_str;
+ unsigned long ev_caps;
/* The laptop platform drivers issue hotkey events through its own input
* device or the i8042 keyboard device. Now we filter out the PC Speaker
* and the i8042 devices other than keyboard and assume the rest is the
* input device generated by the laptop platform driver.
*/
platform_dev = udev_device_get_parent_with_subsystem_devtype(dev, "platform", 0);
if (!platform_dev)
@@ -80,12 +83,15 @@
platform_driver = udev_device_get_driver (platform_dev);
dev_name = udev_device_get_sysattr_value (input_dev, "name");
+ ev_caps_str = udev_device_get_sysattr_value (input_dev, "capabilities/ev");
+ ev_caps = strtoul(ev_caps_str ? ev_caps_str : "", NULL, 16);
- /* PC Speaker */
- if (g_strcmp0 (platform_driver, "pcspkr") == 0) {
+ /* Check if the EV_KEY capability is set */
+ if (!(ev_caps & (1 << EV_KEY)))
return NULL;
+
/* i8042 devices */
- } else if (g_strcmp0 (platform_driver, "i8042") == 0) {
+ if (g_strcmp0 (platform_driver, "i8042") == 0) {
if (g_strcmp0 (dev_name, "AT Translated Set 2 keyboard") != 0)
return NULL;
}
--- End Message ---
--- Begin Message ---
Source: urfkill
Source-Version: 0.4.0-1
We believe that the bug you reported is fixed in the latest version of
urfkill, which is due to be installed in the Debian FTP archive.
A summary of the changes between this version and the previous one is
attached.
Thank you for reporting the bug, which will now be closed. If you
have further comments please address them to [email protected],
and the maintainer will reopen the bug report if appropriate.
Debian distribution maintenance software
pp.
Keng-Yu Lin <[email protected]> (supplier of updated urfkill package)
(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing [email protected])
-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA512
Format: 1.8
Date: Tue, 24 Jul 2012 22:48:51 +0800
Source: urfkill
Binary: urfkill liburfkill-glib0 liburfkill-glib-dev liburfkill-glib0-dbg
gir1.2-urfkill-glib0
Architecture: source i386
Version: 0.4.0-1
Distribution: unstable
Urgency: low
Maintainer: Keng-Yu Lin <[email protected]>
Changed-By: Keng-Yu Lin <[email protected]>
Description:
gir1.2-urfkill-glib0 - GObject introspection data for the urfkill library
liburfkill-glib-dev - wireless killswitch management library (development
files)
liburfkill-glib0 - wireless killswitch management library
liburfkill-glib0-dbg - wireless killswitch management library (debug symbols)
urfkill - wireless killswitch management daemon for laptops
Closes: 668888
Changes:
urfkill (0.4.0-1) unstable; urgency=low
.
* New upstream release (Closes: #668888)
* Add Multiarch support
* Bump Standards-Version to 3.9.3
* Changed gir1.2-urfkill-glib0 to introspection section
* Added DM-Upload-Allowed: yes
* Advanced to DH9
* Removed debian/patches/02_add_missing_autogen_sh.patch
* Update debian/copyright format to 1.0
* Add DEB-3 compliant headers in debian/patches/*
Checksums-Sha1:
e23b1b0e80485b8815ead73f58fdc81676be512e 2305 urfkill_0.4.0-1.dsc
b269a1e3f8434f605bbbf01679029383dbcaef4f 320440 urfkill_0.4.0.orig.tar.xz
f006d591b4a839fd666b7974c21d8d8c6cfcbe42 4991 urfkill_0.4.0-1.debian.tar.gz
8760a76196d24bfd291c54a8aef0d87764b67d4c 40474 urfkill_0.4.0-1_i386.deb
dd47944998e23d49e24c871c3d6bc11b948f29a0 12980
liburfkill-glib0_0.4.0-1_i386.deb
f807fa9cc3cb30c69cd5b2da27cf2c3f84d690ef 20460
liburfkill-glib-dev_0.4.0-1_i386.deb
05200d99397238ede0543e35b86588fb3fd98db8 111330
liburfkill-glib0-dbg_0.4.0-1_i386.deb
68f0bf39f71acddb788e77369a2a0738cb76cdb6 4338
gir1.2-urfkill-glib0_0.4.0-1_i386.deb
Checksums-Sha256:
11f31adfe30166c32ea5e01e9bd1dee67f72108177066bea811f0e0cea41ad5e 2305
urfkill_0.4.0-1.dsc
92947d45f04882f789d69d36cd02141ade9421f18f8b0c3c8e22f86f93ab7e48 320440
urfkill_0.4.0.orig.tar.xz
f0850ff4c158b0b57e3986389133a654021974184dad788830028a7e0697dfd4 4991
urfkill_0.4.0-1.debian.tar.gz
bb903715213445393d96e1427032ba7bb62b85448545b034aa70fdfc23316fc9 40474
urfkill_0.4.0-1_i386.deb
8348ea7d187c6c1a1ecc538828c899bd3652ab662d1456666b538dae2f8550a5 12980
liburfkill-glib0_0.4.0-1_i386.deb
978836fddfe85b9f9d4bd0efaff156920f9489ac1b0d7a3b69a79483fc2d6898 20460
liburfkill-glib-dev_0.4.0-1_i386.deb
dd409d5e7b56b232d781a59ec0e0469be858e00bdbab87ea264eb55085af6712 111330
liburfkill-glib0-dbg_0.4.0-1_i386.deb
ad0156ff5e2c95d128616ddae0d44fa8685e1864f6f26e171f6aa3945b70e250 4338
gir1.2-urfkill-glib0_0.4.0-1_i386.deb
Files:
69dae0e612e0e433d0525107a2ac2f38 2305 net optional urfkill_0.4.0-1.dsc
9ca621e9cc7ac97fe04da36a16043965 320440 net optional urfkill_0.4.0.orig.tar.xz
f9a166e2b1a127e39a78441fd74aa29d 4991 net optional
urfkill_0.4.0-1.debian.tar.gz
aba0683b74562350ef6a1bab324411b3 40474 net optional urfkill_0.4.0-1_i386.deb
1040b09d5f7f0ccadaba03a8aad09186 12980 libs optional
liburfkill-glib0_0.4.0-1_i386.deb
f6e43f73c7cea45e4d4c050d61a9eb85 20460 libdevel optional
liburfkill-glib-dev_0.4.0-1_i386.deb
ff811f7042fd8080b4ed35d32f7b2eec 111330 debug extra
liburfkill-glib0-dbg_0.4.0-1_i386.deb
d62483b0b22f1490ba440fa1c461fec0 4338 introspection optional
gir1.2-urfkill-glib0_0.4.0-1_i386.deb
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.12 (GNU/Linux)
iQIcBAEBCgAGBQJQDtINAAoJEPgLgUbQQog2tO4P/iNad6YwcfYKBisWI2NiLz8l
bXY0p9ft/QppYRKgMM93Fy3562VPpzwic9BF9qUofHrUZdR/dIG0oc1TbwkEMCq9
GK21y63KysFP/DRjMdU9qeb5C37IOgh2X9ZDpY5L0vrw3mA8WeDqcuL8o+9wLi6U
zr0kR76AWpv0mzmyPw/fs+/DCjAXTCrl78CzMIRuW+Szc0Sb+KdochrtDRiNXDgO
i9WqaLrg4AZ0Fj6B9+zq7pzpgWFkG5jEmssjDYv2B9YJDeTIiwNstAvlkx3W7LYv
VflBRqcoE/PplH+x9Ye0Zoc90CZZBakpiEZccVkFM/Xgvfl2BKHWVtQag2IBn7uy
438ek99Mkj51jOfrRrBMkYdCc2w7hlvebquZLkJkCEHKdYMbZKCud1p/+rZKAVsU
x82qKT7fy5TUYml93q6ReOGU71APfYHicE4CxfQfjcMrGSZUQ3D7QkXUaQ6AaFUH
7ngjVGXkW1IVrEryJ7G4phalfoyqUEnCy5f5ldIWkOo7gMrtiHq1aqhBhUT/m22G
dO+HlC+/RUOL7+ro1zOBJduQmvGhimx5J83x4mHhwd40uQhHqOiWJiU7ucYZMuV0
OtHNIkb8ZbEbh1AnId2HxNAQwgA+1zMyRvg6dwgrBpWg54AXWSZM5VSqq50vRDqe
qC4X658akPYG1+xNoAjX
=bAIv
-----END PGP SIGNATURE-----
--- End Message ---
@@ -65,11 +65,14 @@
/* The laptop platform drivers issue hotkey events through its own input
- * device or the i8042 keyboard device. Now we filter out the PC Speaker
- * and the i8042 devices other than keyboard and assume the rest is the
- * input device generated by the laptop platform driver.
+ * device or the i8042 keyboard device. Now we filter out devices
+ * without the EV_KEY capability and the i8042 devices other than
+ * keyboard and assume the rest is the input device generated by the
+ * laptop platform driver.
*/
platform_dev = udev_device_get_parent_with_subsystem_devtype(dev, "platform", 0);